@@ -315,17 +315,8 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
 
     env.Default(targets)
 
-    import SCons.Node
-    files = set(targets)
-    for t in targets:
-        print t
-        W = SCons.Node.Walker(env.Entry(t))
-        while not W.is_done():
-            N = W.get_next()
-            print N
-            files.add(N)
 
-    env.Command(out, list(files) + [os.path.join(basename, ".sconsign.dblite")], "tar cjf $TARGET $SOURCES")
+    env.Command(out, targets + [basename, os.path.join(basename, ".sconsign.dblite")], "tar cjf $TARGET $SOURCES")
 
     return targets, sources, basename
 
